@@ -1,6 +1,6 @@
 #!/usr/bin/python2.3
 import sys, os
-if os.getcwd()[-4:] == "test":
+if os.getcwdu()[-4:] == "test":
     sys.path.insert(0, "..")
 else:
     sys.path.insert(0, ".")
