@@ -9,9 +9,9 @@ build() {
   cp solfege.bat solfegedebug.bat.tmp
   echo "pause">> solfegedebug.bat.tmp
   sed -e "s/python.exe solfege/python.exe solfege --debug/" solfegedebug.bat.tmp > solfegedebug.bat
-  #./configure PYTHON=/c/Python25/python.exe --disable-pygtk-test --enable-winmidi
-  #make skipmanual=yes PYTHON_INCLUDES=-I/c/Python25/include
-  #make winbuild
+  ./configure PYTHON=/c/Python25/python.exe --disable-pygtk-test --enable-winmidi
+  make skipmanual=yes PYTHON_INCLUDES=-I/c/Python25/include
+  make winbuild
 }
 
 prepare_installer() {
